0.9.9 API documentation: log_base.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

log_base.hpp
Go to the documentation of this file.
1
13 #pragma once
14
15 // Dependency:
16 #include "../glm.hpp"
17
18 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
19 # ifndef GLM_ENABLE_EXPERIMENTAL
20 # pragma message("GLM: GLM_GTX_log_base is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
21 # else
22 # pragma message("GLM: GLM_GTX_log_base extension included")
23 # endif
24 #endif
25
26 namespace glm
27 {
30
33 template<typename genType>
34 GLM_FUNC_DECL genType log(
35 genType const& x,
36 genType const& base);
37
40 template<length_t L, typename T, qualifier Q>
41 GLM_FUNC_DECL vec<L, T, Q> sign(
42 vec<L, T, Q> const& x,
43 vec<L, T, Q> const& base);
44
46 }//namespace glm
47
48 #include "log_base.inl"
glm::sign
GLM_FUNC_DECL vec< L, T, Q > sign(vec< L, T, Q > const &x, vec< L, T, Q > const &base)
Logarithm for any base.
glm::log
GLM_FUNC_DECL genType log(genType const &x, genType const &base)
Logarithm for any base.
glm
Definition: common.hpp:20